@@ -102,6 +102,9 @@ from mx_platform_python.model.tagging_update_request import TaggingUpdateRequest
 from mx_platform_python.model.tagging_update_request_body import TaggingUpdateRequestBody
 from mx_platform_python.model.taggings_response_body import TaggingsResponseBody
 from mx_platform_python.model.tags_response_body import TagsResponseBody
+from mx_platform_python.model.tax_document_response import TaxDocumentResponse
+from mx_platform_python.model.tax_document_response_body import TaxDocumentResponseBody
+from mx_platform_python.model.tax_documents_response_body import TaxDocumentsResponseBody
 from mx_platform_python.model.transaction_response import TransactionResponse
 from mx_platform_python.model.transaction_response_body import TransactionResponseBody
 from mx_platform_python.model.transaction_rule_create_request import TransactionRuleCreateRequest
